==> wordpress_0.7.3.tar.gz: wordpress-0.7.3/src/wppagegraphicslistitem.cpp <==
#include <QPoint>
#include <QRect>
#include <QPainter>

#include "wppagegraphicslistitem.h"
#include "WPData.h"
#include "themedatastorage.h"

WPPageGraphicsListItem::Geometry WPPageGraphicsListItem::iGeometry;

WPPageGraphicsListItem::WPPageGraphicsListItem(WPPage aPage, BusyIndicator& aBusyIndicator, ThemeData& aThemeData)
    : WPGraphicsListItem(aBusyIndicator, aThemeData)
    , iPage(aPage)
{
    setObjectName(QString::fromLatin1("WPPageListItem"));
    iDate = aPage->GetShortLocalTimeString(); 
}

WPPageGraphicsListItem::~WPPageGraphicsListItem()
{
}

WPPage WPPageGraphicsListItem::GetPage() 
{
    return iPage;
}

bool WPPageGraphicsListItem::operator<(WPPageGraphicsListItem const & other)
{
    return (iPage->GetLocalTime() < other.iPage->GetLocalTime());
}

void WPPageGraphicsListItem::paintContent(QPainter* painter, const QStyleOptionGraphicsItem* /*option*/, QWidget* /*widget*/)
{   
    painter->setPen(Qt::black);

    painter->setFont(*iThemeData.iListTitleFont);
    painter->drawText(iGeometry.iTitle, iTitle);

    painter->setFont(*iThemeData.iListInfoFont);
    painter->drawText(iGeometry.iAuthor, "by " + iPage->iWpAuthorDisplayName);

    painter->setFont(*iThemeData.iListDetailFont);
    painter->drawText(iGeometry.iDate, iDate);
}

bool WPPageGraphicsListItem::IsBusy()
{
    return iPage->IsBusy();
}

bool WPPageGraphicsListItem::HasError()
{
	return iPage->iError;
}

void WPPageGraphicsListItem::handleGeomeryChange()
{
    iGeometry.update(size(), iThemeData);
    
    calculateElidedTexts();

    setMinimumHeight(iGeometry.height());
}

void WPPageGraphicsListItem::calculateElidedTexts()
{
    QFontMetrics titleFm(*iThemeData.iListTitleFont);
    iTitle = titleFm.elidedText(iPage->iTitle, Qt::ElideRight, int(iGeometry.iTitle.width()));
}

void WPPageGraphicsListItem::Geometry::update (const QSizeF &size, const ThemeData &theme)
{
    if (iCachedSize == size)
        // fresh
        return;

    else
        iCachedSize = size;

    // XXX: recalc boundingRect by hand
    int itemPadding = theme.iListItemPadding;
    int padding = theme.iListItemShadowMargin + itemPadding;
    int width = size.width() - 2 * padding;
    
    // Font metrics
    QFontMetrics titleFont (*theme.iListTitleFont);
    QFontMetrics infoFont (*theme.iListInfoFont);
    QFontMetrics detailFont (*theme.iListDetailFont);

    iTitle.setRect(padding, padding, width, titleFont.height());
    iAuthor.setRect(padding, iTitle.bottom() + itemPadding, width, infoFont.height());
    iDate.setRect(padding, iAuthor.bottom() + 3 * itemPadding, width, detailFont.height());

    iHeight = iDate.bottom() + padding;
}

==> wordpress_0.7.4.tar.gz: wordpress-0.7.4/src/wppagegraphicslistitem.cpp <==
#include <QPoint>
#include <QRect>
#include <QPainter>

#include "wppagegraphicslistitem.h"
#include "WPData.h"
#include "themedatastorage.h"
#include "HtmlPainter.h"

WPPageGraphicsListItem::Geometry WPPageGraphicsListItem::iGeometry;

WPPageGraphicsListItem::WPPageGraphicsListItem(WPPage aPage, BusyIndicator& aBusyIndicator, ThemeData& aThemeData)
    : WPGraphicsListItem(aBusyIndicator, aThemeData)
    , iPage(aPage)
{
    setObjectName(QString::fromLatin1("WPPageListItem"));
    iDate = aPage->GetShortLocalTimeString();
    
    iTitle = new HtmlPainter(HtmlPainter::Title, true);
    iTitle->setContent(iPage->iTitle);
}

WPPageGraphicsListItem::~WPPageGraphicsListItem()
{
}

WPPage WPPageGraphicsListItem::GetPage() 
{
    return iPage;
}

bool WPPageGraphicsListItem::operator<(WPPageGraphicsListItem const & other)
{
    return (iPage->GetLocalTime() < other.iPage->GetLocalTime());
}

void WPPageGraphicsListItem::paintContent(QPainter* painter, const QStyleOptionGraphicsItem* /*option*/, QWidget* /*widget*/)
{   
    painter->setPen(Qt::black);

    iTitle->setWidthAndMode(iGeometry.iTitle.width(), true);
    iTitle->paint(painter, iGeometry.iTitle);

    painter->setFont(*iThemeData.iListInfoFont);
    painter->drawText(iGeometry.iAuthor, "by " + iPage->iWpAuthorDisplayName);

    painter->setFont(*iThemeData.iListDetailFont);
    painter->drawText(iGeometry.iDate, iDate);
}

bool WPPageGraphicsListItem::IsBusy()
{
    return iPage->IsBusy();
}

bool WPPageGraphicsListItem::HasError()
{
	return iPage->iError;
}

void WPPageGraphicsListItem::handleGeomeryChange()
{
    iGeometry.update(*this);
    setMinimumHeight(iGeometry.height());
}

void WPPageGraphicsListItem::Geometry::update (WPPageGraphicsListItem & parent)
{
    const QSizeF size = parent.size();
    const ThemeData &theme = parent.iThemeData;
    
    if (iCachedSize == size)
        // fresh
        return;
    else
        iCachedSize = size;

    // XXX: recalc boundingRect by hand
    int itemPadding = theme.iListItemPadding;
    int padding = theme.iListItemShadowMargin + itemPadding;
    int width = size.width() - 2 * padding;
    
    // Font metrics
    QFontMetrics infoFont (*theme.iListInfoFont);
    QFontMetrics detailFont (*theme.iListDetailFont);

    iTitle.setRect(padding, padding, width, parent.iTitle->fontMetrics().height());
    iAuthor.setRect(padding, iTitle.bottom() + itemPadding, width, infoFont.height());
    iDate.setRect(padding, iAuthor.bottom() + 3 * itemPadding, width, detailFont.height());

    iHeight = iDate.bottom() + padding;
}
